/**
 * Representation of a single sample of sensor values from the Finch.  In particular,
 * a sample contains:
 * <UL>
 * <LI>  The light levels (left and right channels)
 * <LI>  The acceleration levels (X, Y, and Z) in units of 'g'
 * <LI>  The obstacle values (boolean representing whether an obstacle is there or not)
 *     		for the left and right sensors
 * <LI>  The temperature level (in Celsius)
 * </UL>
 * @author Andrew H. Fagg and Steven Ness
 *
 */ 

public class FinchSensor implements Comparable2
{
	/**
	 * Holds the array of light values
	 */
	private int light[];
	
	/**
	 * Holds the array of acceleration values
	 */
	private double acceleration[];
	
	/**
	 * Holds the array of obstacle values
	 */
	private boolean obstacle[];
	
	/**
	 * Holds the temperature value
	 */
	private double temperature;
	
	/**
	 * Primary constructor
	 * 
	 * @param light			2-element array of light levels
	 * @param acceleration	3-element array of acceleration values
	 * @param obstacle		2-element array of obstacle values
	 * @param temperature	Temperature
	 */
	public FinchSensor(int light[], double acceleration[], 
			boolean obstacle[], double temperature)
	{
		this.light = light;
		this.acceleration = acceleration;
		this.obstacle = obstacle;
		this.temperature = temperature;
	}
	
	/**
	 * Method is used to compare integers a and b
	 * <P>
	 * @param a
	 * @param b
	 * @return	1 if <code>a</code> is greater than <code>b</code>, -1 if
	 * 				the reverse is true, and 0 if they are equal
	 */
	private int compareTo(int a, int b){
		if(a > b) return(1);
		if(a == b) return(0);
		return(-1);
	}
	
	/**
	 * Method used to compare doubles
	 * <P>
	 * @param a
	 * @param b
	 * @return	1 if <code>a</code> is greater than <code>b</code>, -1 if
	 * 				the reverse is true, and 0 if they are equal
	 */
	private int compareTo(double a, double b){
		if(a > b) return(1);
		if(a == b) return(0);
		return(-1);
	}
	
	
	/**
	 * Compute the magnitude (or length) of a vector (specifically, the L2 norm)
	 * <P>
	 * 
	 * @param vec	An array of doubles
	 * @return		The vector magnitude
	 */
	
	private double arrayMagnitude(double[] vec){
		double mag = 0.0;
		
		for(int i = 0; i < vec.length; ++i){
			mag += vec[i]*vec[i];
		}
		return(Math.sqrt(mag));
	}

	/**
	 * Compare two objects based on a specific member variable 
	 * (specified by parameter var)
	 * 
	 * <P>
	 * 
	 * @param	obj		The passed object to compare against
	 * @param	var		The key to compare with
	 * @return	1 if this.var > obj.var <BR> 0 if this.var == obj.var<BR> and -1 if this.var < obj.var	
	 */
	
	public int compareTo2(Object obj, VariableType var) 
	{
		// Have we received the specific object classes that we expect?
		if(obj instanceof FinchSensor && var instanceof SensorType) {
			// Yes - perform the comparison
			
			// These are just helpers that keep us from having to constantly 
			//  recast obj and var
			FinchSensor sensor = (FinchSensor) obj;
			SensorType sensorType  = (SensorType) var;
			
			// The comparison is different depending on which key we have ...
			//  Hint: you can compare enummerated values using the var.equals() method,
			//    which is used implicitly for the switch statement
			
			switch(sensorType){
				case LIGHT_LEFT:
					// What do we do when the left light sensor is requested?
					// FILL CODE IN HERE


					
					// and FILL CODE IN HERE: OTHER CASES
			}

		}
		// This throw() is called only when we receive objects that we were not expecting
		//   (and should not ever happen in this implementation).  We will talk more
		//   about throwing exceptions later in the semester
		
		throw(new ClassCastException("Not compatible types"));

	}

	/**
	 * Overriding the Object toString method
	 * 
	 * @return	A representation of this object as a String
	 */
	public String toString()
	{
		return(this.light[0] + " " +
				this.light[1] + " " +
				this.acceleration[0] + " " +
				this.acceleration[1] + " " +
				this.acceleration[2] + " " +
				this.obstacle[0] + " " +
				this.obstacle[1] + " " +
				this.temperature);
	}
}