/**
 * An implementation of a particular VariableType that represents the 
 *   subset of the different sensor channels that can be sampled from
 *   the Finch.  In particular, this subset is those sensor channels that
 *   we will want to sort our samples by.
 * 
 * <P>
 * 
 * @author Andrew H. Fagg and Steven Ness
 *
 */

public enum SensorType implements VariableType {
	/* The legal enummerated values
	 *   Note: in java, the different enummerated values are actually implemented
	 *   as instances of this class.
	 *   
	 *   In the user classes, the different enummerated values can be referenced using:
	 *   SensorType.LIGHT_LEFT
	 *   (this is the same syntax you would use to reference public constants (statics)
	 *   provided by a class).
	 */
	
	LIGHT_LEFT ("Light left"),				// Refer to the LEFT light sensor
	LIGHT_RIGHT ("Light right"),			// Right light sensor
	ACCEL_X ("Acceleration X"),				// X component of the acceleration vector
	ACCEL_Y ("Acceleration Y"),				// Y component
	ACCEL_Z ("Acceleration Z"),				// Z component
	ACCEL_MAG ("Accleration Magnitude"),	// Length of the acceleration vector
	TEMPERATURE ("Temperature");			// Temperature
	
	// The string that is used when the particular ennumerated value is printed
	private String printname;
	
	/**
	 * Constructor is private to this class: it is only used in the 
	 *    definition of the various enummerated values. 
	 *    
	 * @param name	The string that is returned by this instance 
	 */
	private SensorType(String name)
	{
		this.printname = name;
	}
	
	/**
	 *  toString() override
	 *  
	 *  @return Returns the string that describes this enummerated value
	 */
	
	public String toString()
	{
		return(this.printname);
	}
	
}
